# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: metronomo.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'metronomo.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0fmetronomo.proto\x12\tmetronomo\"\x08\n\x06IdnArg\"\x8a\x01\n\x06IdnRet\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x15\n\rserial_number\x18\x03 \x01(\t\x12\x11\n\trpi_model\x18\x04 \x01(\t\x12\x0f\n\x07rpi_soc\x18\x05 \x01(\t\x12\x12\n\nrpi_serial\x18\x06 \x01(\t\x12\x12\n\npcb_serial\x18\x07 \x01(\t\"\x18\n\x07\x45\x63hoArg\x12\r\n\x05value\x18\x01 \x01(\x05\"\x18\n\x07\x45\x63hoRet\x12\r\n\x05value\x18\x01 \x01(\x05\"\x1b\n\x08SleepArg\x12\x0f\n\x07seconds\x18\x01 \x01(\x02\"\n\n\x08SleepRet\"\r\n\x0b\x43lkResetArg\"\r\n\x0b\x43lkResetRet\"\x0f\n\rClkProgramArg\"\x0f\n\rClkProgramRet\"0\n\tClkRefArg\x12\x10\n\x08\x65xternal\x18\x01 \x01(\x08\x12\x11\n\tfrequency\x18\x02 \x01(\x01\"\x1e\n\tClkRefRet\x12\x11\n\tfrequency\x18\x01 \x01(\x01\"\"\n\rClkOutFreqArg\x12\x11\n\tfrequency\x18\x01 \x01(\x01\"\"\n\rClkOutFreqRet\x12\x11\n\tfrequency\x18\x01 \x01(\x01\"\x10\n\x0eWaitForLockArg\"&\n\x0eWaitForLockRet\x12\x14\n\x0cmilliseconds\x18\x01 \x01(\r\"\r\n\x0bIsLockedArg\"\x1d\n\x0bIsLockedRet\x12\x0e\n\x06locked\x18\x01 \x01(\x08\"7\n\x10SetSysrefModeArg\x12#\n\x04mode\x18\x01 \x01(\x0e\x32\x15.metronomo.SysrefMode\"\x12\n\x10SetSysrefModeRet\"\x0c\n\nSyncOutArg\"\x0c\n\nSyncOutRet\"\x1c\n\x0bTestFailArg\x12\r\n\x05value\x18\x01 \x01(\x05\"\r\n\x0bTestFailRet*@\n\nSysrefMode\x12\x16\n\x12SYSREF_MODE_PULSER\x10\x00\x12\x1a\n\x16SYSREF_MODE_CONTINUOUS\x10\x01\x32\xd2\x05\n\tMetronomo\x12+\n\x03Idn\x12\x11.metronomo.IdnArg\x1a\x11.metronomo.IdnRet\x12.\n\x04\x45\x63ho\x12\x12.metronomo.EchoArg\x1a\x12.metronomo.EchoRet\x12\x31\n\x05Sleep\x12\x13.metronomo.SleepArg\x1a\x13.metronomo.SleepRet\x12:\n\x08\x43lkReset\x12\x16.metronomo.ClkResetArg\x1a\x16.metronomo.ClkResetRet\x12@\n\nClkProgram\x12\x18.metronomo.ClkProgramArg\x1a\x18.metronomo.ClkProgramRet\x12\x34\n\x06\x43lkRef\x12\x14.metronomo.ClkRefArg\x1a\x14.metronomo.ClkRefRet\x12@\n\nClkOutFreq\x12\x18.metronomo.ClkOutFreqArg\x1a\x18.metronomo.ClkOutFreqRet\x12\x43\n\x0bWaitForLock\x12\x19.metronomo.WaitForLockArg\x1a\x19.metronomo.WaitForLockRet\x12:\n\x08IsLocked\x12\x16.metronomo.IsLockedArg\x1a\x16.metronomo.IsLockedRet\x12I\n\rSetSysrefMode\x12\x1b.metronomo.SetSysrefModeArg\x1a\x1b.metronomo.SetSysrefModeRet\x12\x37\n\x07SyncOut\x12\x15.metronomo.SyncOutArg\x1a\x15.metronomo.SyncOutRet\x12:\n\x08TestFail\x12\x16.metronomo.TestFailArg\x1a\x16.metronomo.TestFailRetb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'metronomo_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SYSREFMODE']._serialized_start=746
  _globals['_SYSREFMODE']._serialized_end=810
  _globals['_IDNARG']._serialized_start=30
  _globals['_IDNARG']._serialized_end=38
  _globals['_IDNRET']._serialized_start=41
  _globals['_IDNRET']._serialized_end=179
  _globals['_ECHOARG']._serialized_start=181
  _globals['_ECHOARG']._serialized_end=205
  _globals['_ECHORET']._serialized_start=207
  _globals['_ECHORET']._serialized_end=231
  _globals['_SLEEPARG']._serialized_start=233
  _globals['_SLEEPARG']._serialized_end=260
  _globals['_SLEEPRET']._serialized_start=262
  _globals['_SLEEPRET']._serialized_end=272
  _globals['_CLKRESETARG']._serialized_start=274
  _globals['_CLKRESETARG']._serialized_end=287
  _globals['_CLKRESETRET']._serialized_start=289
  _globals['_CLKRESETRET']._serialized_end=302
  _globals['_CLKPROGRAMARG']._serialized_start=304
  _globals['_CLKPROGRAMARG']._serialized_end=319
  _globals['_CLKPROGRAMRET']._serialized_start=321
  _globals['_CLKPROGRAMRET']._serialized_end=336
  _globals['_CLKREFARG']._serialized_start=338
  _globals['_CLKREFARG']._serialized_end=386
  _globals['_CLKREFRET']._serialized_start=388
  _globals['_CLKREFRET']._serialized_end=418
  _globals['_CLKOUTFREQARG']._serialized_start=420
  _globals['_CLKOUTFREQARG']._serialized_end=454
  _globals['_CLKOUTFREQRET']._serialized_start=456
  _globals['_CLKOUTFREQRET']._serialized_end=490
  _globals['_WAITFORLOCKARG']._serialized_start=492
  _globals['_WAITFORLOCKARG']._serialized_end=508
  _globals['_WAITFORLOCKRET']._serialized_start=510
  _globals['_WAITFORLOCKRET']._serialized_end=548
  _globals['_ISLOCKEDARG']._serialized_start=550
  _globals['_ISLOCKEDARG']._serialized_end=563
  _globals['_ISLOCKEDRET']._serialized_start=565
  _globals['_ISLOCKEDRET']._serialized_end=594
  _globals['_SETSYSREFMODEARG']._serialized_start=596
  _globals['_SETSYSREFMODEARG']._serialized_end=651
  _globals['_SETSYSREFMODERET']._serialized_start=653
  _globals['_SETSYSREFMODERET']._serialized_end=671
  _globals['_SYNCOUTARG']._serialized_start=673
  _globals['_SYNCOUTARG']._serialized_end=685
  _globals['_SYNCOUTRET']._serialized_start=687
  _globals['_SYNCOUTRET']._serialized_end=699
  _globals['_TESTFAILARG']._serialized_start=701
  _globals['_TESTFAILARG']._serialized_end=729
  _globals['_TESTFAILRET']._serialized_start=731
  _globals['_TESTFAILRET']._serialized_end=744
  _globals['_METRONOMO']._serialized_start=813
  _globals['_METRONOMO']._serialized_end=1535
# @@protoc_insertion_point(module_scope)
